# alphanum

Simple Python library to generate pseudo-random alphanumeric strings of
arbitrary length. Requires Python 3.6+.

## Usage

```python
import alphanum

foo = alphanum.generate(10)
print(foo)
```

## License

Copyright (c) 2020 Cody Logan. MIT licensed.
